==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebTabsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabComponentEventArgsDescriptionMetadata } from "./WebTabComponentEventArgsDescriptionMetadata";
import { WebTabsDescription } from "./WebTabsDescription";
/**
 * @hidden
 */
var WebTabsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTabsDescriptionMetadata, _super);
    function WebTabsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabsDescriptionMetadata.b = function (a) {
        if (WebTabsDescriptionMetadata.a == null) {
            WebTabsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabsDescriptionMetadata.c(WebTabsDescriptionMetadata.a);
        }
        if (a.g(WebTabsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebTabsDescriptionMetadata.a);
        WebTabComponentEventArgsDescriptionMetadata.d(a);
    };
    WebTabsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Tabs");
        a.item("Alignment", "ExportedType:string:TabsAlignment");
        a.item("Alignment@names", "Start;End;Center;Justify");
        a.item("Activation", "ExportedType:string:TabsActivation");
        a.item("Activation@names", "Manual;Auto");
        a.item("ChangeRef", "EventRef::change");
    };
    WebTabsDescriptionMetadata.d = function (a) {
        WebTabsDescriptionMetadata.b(a);
        a.u("WebTabs", function () { return new WebTabsDescription(); });
        a.t("WebTabs", WebTabsDescriptionMetadata.a);
    };
    WebTabsDescriptionMetadata.$t = markType(WebTabsDescriptionMetadata, 'WebTabsDescriptionMetadata');
    WebTabsDescriptionMetadata.a = null;
    return WebTabsDescriptionMetadata;
}(Base));
export { WebTabsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebTabsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabComponentEventArgsDescriptionMetadata } from "./WebTabComponentEventArgsDescriptionMetadata";
import { WebTabsDescription } from "./WebTabsDescription";
/**
 * @hidden
 */
var WebTabsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTabsDescriptionMetadata, _super);
    function WebTabsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabsDescriptionMetadata.b = function (a) {
        if (WebTabsDescriptionMetadata.a == null) {
            WebTabsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabsDescriptionMetadata.c(WebTabsDescriptionMetadata.a);
        }
        if (a.j(WebTabsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebTabsDescriptionMetadata.a);
        WebTabComponentEventArgsDescriptionMetadata.d(a);
    };
    WebTabsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Tabs");
        a.item("__tagNameWC", "String:igc-tabs");
        a.item("Alignment", "ExportedType:string:TabsAlignment");
        a.item("Alignment@names", "Start;End;Center;Justify");
        a.item("Activation", "ExportedType:string:TabsActivation");
        a.item("Activation@names", "Manual;Auto");
        a.item("ChangeRef", "EventRef::change");
    };
    WebTabsDescriptionMetadata.d = function (a) {
        WebTabsDescriptionMetadata.b(a);
        a.aa("WebTabs", function () { return new WebTabsDescription(); });
        a.z("WebTabs", WebTabsDescriptionMetadata.a);
    };
    WebTabsDescriptionMetadata.$t = markType(WebTabsDescriptionMetadata, 'WebTabsDescriptionMetadata');
    WebTabsDescriptionMetadata.a = null;
    return WebTabsDescriptionMetadata;
}(Base));
export { WebTabsDescriptionMetadata };
